@@ -102,6 +102,7 @@ from neutron_lib.api.definitions import qos_default
 from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_port_network_policy
 from neutron_lib.api.definitions import qos_pps_minimum_rule
+from neutron_lib.api.definitions import qos_pps_minimum_rule_alias
 from neutron_lib.api.definitions import qos_pps_rule
 from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rules_alias
@@ -119,6 +120,7 @@ from neutron_lib.api.definitions import routerservicetype
 from neutron_lib.api.definitions import security_groups_normalized_cidr
 from neutron_lib.api.definitions import security_groups_port_filtering
 from neutron_lib.api.definitions import security_groups_remote_address_group
+from neutron_lib.api.definitions import security_groups_shared_filtering
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import segments_peer_subnet_host_routes
 from neutron_lib.api.definitions import servicetype
@@ -238,6 +240,7 @@ _ALL_API_DEFINITIONS = {
     qos_gateway_ip,
     qos_port_network_policy,
     qos_pps_minimum_rule,
+    qos_pps_minimum_rule_alias,
     qos_pps_rule,
     qos_rule_type_details,
     qos_rules_alias,
@@ -255,6 +258,7 @@ _ALL_API_DEFINITIONS = {
     security_groups_normalized_cidr,
     security_groups_port_filtering,
     security_groups_remote_address_group,
+    security_groups_shared_filtering,
     segment,
     segments_peer_subnet_host_routes,
     servicetype,
